vlc | branch: master | David Fuhrmann <[email protected]> | Sat Aug 16 
13:20:55 2014 +0200| [ad30beeabe8228616b3cd92b88e07f8165f28c0d] | committer: 
David Fuhrmann

macosx: Do not resume playback if start, stop or run-time is set

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=ad30beeabe8228616b3cd92b88e07f8165f28c0d
---

 modules/gui/macosx/playlist.m |   11 +++++------
 1 file changed, 5 insertions(+), 6 deletions(-)

diff --git a/modules/gui/macosx/playlist.m b/modules/gui/macosx/playlist.m
index b41ef77..09ddb9d 100644
--- a/modules/gui/macosx/playlist.m
+++ b/modules/gui/macosx/playlist.m
@@ -1485,12 +1485,11 @@
         if (!p_item)
             return;
 
-        /* allow the user to over-write the start-time */
-        if (p_item->i_options > 0) {
-            for (int x = 0; x < p_item->i_options; x++) {
-                if (strstr(p_item->ppsz_options[x],"start-time"))
-                    return;
-            }
+        /* allow the user to over-write the start/stop/run-time */
+        if (var_GetFloat(p_input_thread, "run-time") > 0 ||
+            var_GetFloat(p_input_thread, "start-time") > 0 ||
+            var_GetFloat(p_input_thread, "stop-time") > 0) {
+            return;
         }
 
         char *psz_url = decode_URI(input_item_GetURI(p_item));

_______________________________________________
vlc-commits mailing list
[email protected]
https://mailman.videolan.org/listinfo/vlc-commits

Reply via email to